Statistics class

Utility class for statistical calculations.

Constructors

Statistics()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

mean(List<double> data) → double
Calculates the mean (average) of a list of numbers.
standardDeviation(List<double> data) → double
Calculates the standard deviation of a list of numbers.